==> 0.0.1%2B1.tar.gz: lib/models/IR5Pointage.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5Member.dart" show IR5Member;
import 'IR5PointageConso.dart' show IR5PointageConso;
import 'IR5PointagePay.dart' show IR5PointagePay;

// --------------------------------------------------------------------------------
part 'IR5Pointage.g.dart';

/** Histo aka Big Book */
@JsonSerializable(explicitToJson: true)
class IR5Pointage {
  IR5Pointage({
    required this.NoTbl,
    required this.SsTbl,
    this.Nom,
    this.Descr,
    this.TblType,
    this.Cvts,
    this.TblMode,
    this.OUFTIState,
    this.DteOuv,
    this.DteClot,
    this.NoHre,
    this.NoSales,
    this.GUID,
    this.DetailsFmt,
    this.StationNum,
    this.StationFiscalId,
    this.ProprioNo,
    this.ProprioNom,
    this.MemberCard,
    this.Member,
    this.Tariff,
    this.TariffIn,
    this.TariffOut,
    required this.Consos,
    required this.Pays,
    required this.Details,
    this.Total,
    this.Base,
    this.Tax,
    this.EnCaisse,
  });

  factory IR5Pointage.fromJson(Map<String, dynamic>? json) => _$IR5PointageFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5PointageToJson(this);

  @JsonKey(defaultValue: '')
  final String NoTbl;
  @JsonKey(defaultValue: '')
  final String SsTbl;

  /** Free Table Name. ex: nom + prénom + gsm du client */
  final String? Nom;

  /** MemberName|TblName|... Only in GetPointage Answer */
  final String? Descr;
  final num? TblType;
  final num? Cvts;

  /** TblMode: 0:ReadOnly | 1:ReadWrite| 2:TrainingReadOnly | 3:TrainingReadWrite */
  final num? TblMode;
  final String? OUFTIState;
  final String? DteOuv;
  final String? DteClot;
  final num? NoHre;

  /** Sales Number. A Sale can be composed of multiple <NoSeq> blocks */
  final num? NoSales;
  final String? GUID;

  /** DetailsFmt: Details | Addition | AddBySsAdd | AddBySeq. Only in SetPointage Request */
  final String? DetailsFmt;
  final num? StationNum;

  /** Station FiscalId */
  final String? StationFiscalId;
  final num? ProprioNo;
  final String? ProprioNom;

  /** Member NumCard. numéro identifiant du personnel (alphanum) */
  final String? MemberCard;
  final IR5Member? Member;

  /** Tariff used / to use (TariffIn,TariffOut Only in GetPointage Answer) */
  final num? Tariff;
  final num? TariffIn;
  final num? TariffOut;
  @JsonKey(defaultValue: [])
  final List<IR5PointageConso> Consos;
  @JsonKey(defaultValue: [])
  final List<IR5PointagePay> Pays;
  @JsonKey(defaultValue: [])
  final List<dynamic> Details;

  /** Totals Only in GetPointage Answer) */
  final num? Total;

  /** Total Price without VAT
   * ActionFlag:
   * -----------
   * # FreeVoucherInfo : Total Value of New FreeVoucher Generated (PointsTaked*Etab.PointValue)
   */
  final num? Base;
  final num? Tax;
  final num? EnCaisse;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5Pointage.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5Member.dart" show IR5Member;
import 'IR5PointageConso.dart' show IR5PointageConso;
import 'IR5PointagePay.dart' show IR5PointagePay;

// --------------------------------------------------------------------------------
part 'IR5Pointage.g.dart';

/** Histo aka Big Book */
@JsonSerializable(explicitToJson: true)
class IR5Pointage {
  IR5Pointage({
    required this.NoTbl,
    required this.SsTbl,
    this.Nom,
    this.Descr,
    this.TblType,
    this.Cvts,
    this.TblMode,
    this.OUFTIState,
    this.DteOuv,
    this.DteClot,
    this.NoHre,
    this.NoSales,
    this.GUID,
    this.DetailsFmt,
    this.StationNum,
    this.StationFiscalId,
    this.ProprioNo,
    this.ProprioNom,
    this.MemberCard,
    this.Member,
    this.Tariff,
    this.TariffIn,
    this.TariffOut,
    required this.Consos,
    required this.Pays,
    required this.Details,
    this.Total,
    this.Base,
    this.Tax,
    this.EnCaisse,
  });

  factory IR5Pointage.fromJson(Map<String, dynamic>? json) =>
      _$IR5PointageFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5PointageToJson(this);

  @JsonKey(defaultValue: '')
  final String NoTbl;
  @JsonKey(defaultValue: '')
  final String SsTbl;

  /** Free Table Name. ex: nom + prénom + gsm du client */
  final String? Nom;

  /** MemberName|TblName|... Only in GetPointage Answer */
  final String? Descr;
  final num? TblType;
  final num? Cvts;

  /** TblMode: 0:ReadOnly | 1:ReadWrite| 2:TrainingReadOnly | 3:TrainingReadWrite */
  final num? TblMode;
  final String? OUFTIState;
  final String? DteOuv;
  final String? DteClot;
  final num? NoHre;

  /** Sales Number. A Sale can be composed of multiple <NoSeq> blocks */
  final num? NoSales;
  final String? GUID;

  /** DetailsFmt: Details | Addition | AddBySsAdd | AddBySeq. Only in SetPointage Request */
  final String? DetailsFmt;
  final num? StationNum;

  /** Station FiscalId */
  final String? StationFiscalId;
  final num? ProprioNo;
  final String? ProprioNom;

  /** Member NumCard. numéro identifiant du personnel (alphanum) */
  final String? MemberCard;
  final IR5Member? Member;

  /** Tariff used / to use (TariffIn,TariffOut Only in GetPointage Answer) */
  final num? Tariff;
  final num? TariffIn;
  final num? TariffOut;
  @JsonKey(defaultValue: [])
  final List<IR5PointageConso> Consos;
  @JsonKey(defaultValue: [])
  final List<IR5PointagePay> Pays;
  @JsonKey(defaultValue: [])
  final List<dynamic> Details;

  /** Totals Only in GetPointage Answer) */
  final num? Total;

  /** Total Price without VAT
   * ActionFlag:
   * -----------
   * # FreeVoucherInfo : Total Value of New FreeVoucher Generated (PointsTaked*Etab.PointValue)
   */
  final num? Base;
  final num? Tax;
  final num? EnCaisse;
}
